MRC Example Images
~~~~~~~~~~~~~~~~~~

The first example in its compressed (relatively high quality) JPEG2000 form is
924K in size (resolution 2093x2813). The MRC variant is 60K is size (15.4K for
the background, 5K for the foreground, and 40.2K for the mask), the background
is downscaled by a factor 3.


.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien-orig.png
  :height: 468px
  :width: 348px

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien-mrc.png
  :height: 468px
  :width: 348px


Here are the individual MRC components:

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien-mrc-bg.png
  :height: 468px
  :width: 348px

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien-mrc-fg.png
  :height: 468px
  :width: 348px

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien-mrc-mask.png
  :height: 468px
  :width: 348px

In the second example, the original image comes in at 928K, but the MRC variant
at just 28.8K (2.3K for the background, 3.5K for the foreground, 23K for the
mask) - over 30 times smaller.

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien2-orig.png
  :height: 468px
  :width: 348px

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien2-mrc.png
  :height: 468px
  :width: 348px


Here are the individual MRC components:

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien2-mrc-bg.png
  :height: 468px
  :width: 348px

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien2-mrc-fg.png
  :height: 468px
  :width: 348px

.. image:: https://archive.org/~merlijn/projects/archive-pdf-tools/doc-imgs/alien2-mrc-mask.png
  :height: 468px
  :width: 348px
